"""Singleston version configuration."""

__version__ = "1.0.0"
__version_info__ = (1, 0, 0)

RELEASE_DATE = "2025-07-09"
AUTHOR = "Adrien Soursou"
HOMEPAGE = "https://github.com/ChuOkupai/singleston"
DESCRIPTION = "A powerful source file amalgamator for C/C++ projects"
